@@ -54,6 +54,7 @@ LastActiveWindow::LastActiveWindow(TrackedGeneralInfo *trackedInfo)
         }
     });
 
+    connect(m_windowsTracker, &Windows::applicationDataChanged, this, &LastActiveWindow::applicationDataChanged);
     connect(m_windowsTracker, &Windows::windowChanged, this, &LastActiveWindow::windowChanged);
     connect(m_windowsTracker, &Windows::windowRemoved, this, &LastActiveWindow::windowRemoved);
 }
@@ -331,6 +332,13 @@ void LastActiveWindow::setInformation(const WindowInfoWrap &info)
 }
 
 //! PRIVATE SLOTS
+void LastActiveWindow::applicationDataChanged(const WindowId &wid)
+{
+    setAppName(m_windowsTracker->appNameFor(wid));
+    setIcon(m_windowsTracker->iconFor(wid));
+}
+
+
 void LastActiveWindow::windowChanged(const WindowId &wid)
 {
     if (!m_trackedInfo->enabled()) {
