@@ -517,6 +517,7 @@ bool WaylandInterface::windowCanBeDragged(WindowId wid) const
         return (winfo.isValid()
                 && w->isMovable()
                 && !winfo.isMinimized()
+                && inCurrentDesktopActivity(winfo)
                 && !winfo.isPlasmaDesktop());
     }
 
@@ -532,6 +533,7 @@ bool WaylandInterface::windowCanBeMaximized(WindowId wid) const
         return (winfo.isValid()
                 && w->isMaximizeable()
                 && !winfo.isMinimized()
+                && inCurrentDesktopActivity(winfo)
                 && !winfo.isPlasmaDesktop());
     }
 
@@ -559,7 +561,9 @@ void WaylandInterface::requestClose(WindowId wid) const
 
 void WaylandInterface::requestMoveWindow(WindowId wid, QPoint from) const
 {
-    if (windowCanBeDragged(wid)) {
+    WindowInfoWrap wInfo = requestInfo(wid);
+
+    if (windowCanBeDragged(wid) && inCurrentDesktopActivity(wInfo)) {
         auto w = windowFor(wid);
 
         if (w && isValidWindow(w)) {
@@ -599,8 +603,9 @@ void WaylandInterface::requestToggleKeepAbove(WindowId wid) const
 void WaylandInterface::requestToggleMinimized(WindowId wid) const
 {
     auto w = windowFor(wid);
+    WindowInfoWrap wInfo = requestInfo(wid);
 
-    if (w && isValidWindow(w)) {
+    if (w && isValidWindow(w) && inCurrentDesktopActivity(wInfo)) {
 #if KF5_VERSION_MINOR >= 52
         if (!m_currentDesktop.isEmpty()) {
             w->requestEnterVirtualDesktop(m_currentDesktop);
@@ -613,8 +618,9 @@ void WaylandInterface::requestToggleMinimized(WindowId wid) const
 void WaylandInterface::requestToggleMaximized(WindowId wid) const
 {
     auto w = windowFor(wid);
+    WindowInfoWrap wInfo = requestInfo(wid);
 
-    if (w && isValidWindow(w) && windowCanBeMaximized(wid)) {
+    if (w && isValidWindow(w) && windowCanBeMaximized(wid) && inCurrentDesktopActivity(wInfo)) {
 #if KF5_VERSION_MINOR >= 52
         if (!m_currentDesktop.isEmpty()) {
             w->requestEnterVirtualDesktop(m_currentDesktop);
@@ -630,16 +636,16 @@ bool WaylandInterface::isPlasmaDesktop(const KWayland::Client::PlasmaWindow *w)
         return false;
     }
 
-    bool hasScreenGeometry{false};
+    return AbstractWindowInterface::isPlasmaDesktop(w->geometry());
+}
 
-    for (const auto scr : qGuiApp->screens()) {
-        if (!w->geometry().isEmpty() && w->geometry() == scr->geometry()) {
-            hasScreenGeometry = true;
-            break;
-        }
+bool WaylandInterface::isPlasmaPanel(const KWayland::Client::PlasmaWindow *w) const
+{
+    if (!w || (w->appId() != QLatin1String("org.kde.plasmashell"))) {
+        return false;
     }
 
-    return hasScreenGeometry;
+    return AbstractWindowInterface::isPlasmaPanel(w->geometry());
 }
 
 bool WaylandInterface::isValidWindow(const KWayland::Client::PlasmaWindow *w) const
@@ -651,7 +657,7 @@ bool WaylandInterface::isValidWindow(const KWayland::Client::PlasmaWindow *w) co
     //! e.g. widgets explorer, Activities etc. that are not used to hide
     //! the dodge views appropriately
 
-    return w->isValid() && !isPlasmaDesktop(w) && !m_ignoredWindows.contains(w->internalId());
+    return w->isValid() && !isPlasmaDesktop(w) && !m_plasmaPanels.contains(w->internalId()) && !m_ignoredWindows.contains(w->internalId());
 }
 
 void WaylandInterface::windowCreatedProxy(KWayland::Client::PlasmaWindow *w)
@@ -697,10 +703,22 @@ void WaylandInterface::windowCreatedProxy(KWayland::Client::PlasmaWindow *w)
         PlasmaWindow *pW = qobject_cast<PlasmaWindow*>(w);
 
         if (pW && !m_ignoredWindows.contains(pW->internalId() && !isPlasmaDesktop(pW) )) {
+            if (pW->appId() == QLatin1String("org.kde.plasmashell")) {
+                if (isPlasmaDesktop(pW)) {
+                    return;
+                } else if (isPlasmaPanel(pW)) {
+                    registerIgnoredWindow(pW->internalId());
+                }
+            }
+
             considerWindowChanged(pW->internalId());
         }
     });
 
+    if (isPlasmaPanel(w)) {
+        registerPlasmaPanel(w->internalId());
+    }
+
     emit windowAdded(w->internalId());
 
     if (w->appId() == "latte-dock") {
